<?php
/**
 * The template for displaying comments
 *
 * This is the template that displays the area of the page that contains both the current comments
 * and the comment form.
 *
 * @link https://codex.wordpress.org/Template_Hierarchy
 *
 * @package Anza Lite
 */

/*
 * If the current post is protected by a password and
 * the visitor has not yet entered the password we will
 * return early without loading the comments.
 */
if ( post_password_required() ) {
	return;
}
?>

<div id="comments" class="comment-area">

	<?php
	// You can start editing here -- including this comment!
	if ( have_comments() ) : ?>
		<h4>
			<?php
				printf( // WPCS: XSS OK.
					esc_html( _nx( 'One thought on &ldquo;%2$s&rdquo;', '%1$s thoughts on &ldquo;%2$s&rdquo;', get_comments_number(), 'comments title', 'anza-lite' ) ),
					number_format_i18n( get_comments_number() ),
					'<span>' . get_the_title() . '</span>'
				);
			?>
		</h4><!-- .comments-title -->

		<?php if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) : // Are there comments to navigate through? ?>
		<nav id="comment-nav-above" class="navigation comment-navigation" role="navigation">
			<h2 class="screen-reader-text"><?php esc_html_e( 'Comment navigation', 'anza-lite' ); ?></h2>
			<div class="nav-links">

				<div class="nav-previous"><?php previous_comments_link( esc_html__( 'Older Comments', 'anza-lite' ) ); ?></div>
				<div class="nav-next"><?php next_comments_link( esc_html__( 'Newer Comments', 'anza-lite' ) ); ?></div>

			</div><!-- .nav-links -->
		</nav><!-- #comment-nav-above -->
		<?php endif; // Check for comment navigation. ?>

		<ol class="comment-list">
			<?php
				wp_list_comments( array(
					'style'      => 'ul',
					'short_ping' => true,
                    'avatar_size'       => 55,
                    'callback'   => 'anza_post_comments'
				) );
			?>
		</ol><!-- .comment-list -->

		<?php if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) : // Are there comments to navigate through? ?>
		<nav id="comment-nav-below" class="navigation comment-navigation" role="navigation">
			<h2 class="screen-reader-text"><?php esc_html_e( 'Comment navigation', 'anza-lite' ); ?></h2>
			<div class="nav-links">

				<div class="nav-previous"><?php previous_comments_link( esc_html__( 'Older Comments', 'anza-lite' ) ); ?></div>
				<div class="nav-next"><?php next_comments_link( esc_html__( 'Newer Comments', 'anza-lite' ) ); ?></div>

			</div><!-- .nav-links -->
		</nav><!-- #comment-nav-below -->
		<?php
		endif; // Check for comment navigation.

	endif; // Check for have_comments().


	// If comments are closed and there are comments, let's leave a little note, shall we?
	if ( ! comments_open() && get_comments_number() && post_type_supports( get_post_type(), 'comments' ) ) : ?>

		<p class="no-comments"><?php esc_html_e( 'Comments are closed.', 'anza-lite' ); ?></p>
	<?php
	endif;    
	$comments_args = array(        
        'label_submit' => esc_html__( 'Submit Comment', 'anza-lite' ),        
        'title_reply' => esc_html__( 'Leave a Comment', 'anza-lite' ),        
        'fields' => apply_filters( 'comment_form_default_fields', 
            array(
                'author' => '<div class="col-lg-6 col-md-6 col-sm-6 col-xs-12 padd-null-left">
											<span>'.esc_html__( 'Name*', 'anza-lite' ).'</span>
											<div class="single-input">
												<input id="author" name="author" type="text" value="' . esc_attr( $commenter['comment_author'] ) . '" size="30"' .  ( $req ? " aria-required='true'" : '' ) . ' placeholder="'.esc_html__( 'Name', 'anza-lite' ).'" />
											</div> 
										</div>',
                'email'  => '<div class="col-lg-6 col-md-6 col-sm-6 col-xs-12 padd-null-right">
											<span>'.esc_html__( 'Email*', 'anza-lite' ).'</span>
											<div class="single-input">
												<input id="email" name="email" type="text" value="' . esc_attr(  $commenter['comment_author_email'] ) . '" size="30"' . ( $req ? " aria-required='true'" : '' ) . '  placeholder="'.esc_html__( 'Email', 'anza-lite' ).'" />
											</div> 
										</div>',
                'url'    => '' 
            )
        ),
        'comment_notes_after' => '',        
        'comment_field' => '<div class="col-lg-12 col-md-12 col-sm-12 col-xs-12 padd-null">
											<span>'.esc_html__( 'Comment*', 'anza-lite' ).'</span>
											<div class="single-input">
											<textarea name="comment" id="comment" placeholder="'.esc_html__( 'Comment', 'anza-lite' ).'"' . ( $req ? " aria-required='true'" : '' ) . '></textarea>
											</div>
										</div>',
    );
    ?>
    
    <?php    
    comment_form( $comments_args );
	?>
        </div>

</div><!-- #comments -->
